@@ -19,7 +19,15 @@
 #ifndef __ast_h
 #define __ast_h
 
+#include <QtGlobal>
+
+#if QT_VERSION >= 0x050000
+#include <QExplicitlySharedDataPointer>
+#define KShared QSharedData
+#define KSharedPtr QExplicitlySharedDataPointer
+#else
 #include <KSharedPtr>
+#endif
 
 #include <memory>
 #include <QString>
@@ -123,7 +131,7 @@ public:
 };
 
 #else
-#define AUTO_PTR std::auto_ptr
+#define AUTO_PTR std::unique_ptr
 #endif
 
 template <class T> typename T::Node CreateNode()
@@ -1029,6 +1037,13 @@ public:
     }
     void setConstant(AST::Node& constant);
 
+    AST* override()
+    {
+        return m_override.get();
+    }
+
+    void setOverride(AST::Node& override);
+
     GroupAST* exceptionSpecification()
     {
         return m_exceptionSpecification.get();
@@ -1043,6 +1058,7 @@ private:
     QList<AST*> m_arrayDimensionList;
     AUTO_PTR<class ParameterDeclarationClauseAST> m_parameterDeclarationClause;
     AST::Node m_constant;
+    AST::Node m_override;
     GroupAST::Node m_exceptionSpecification;
 
 private:
